# STNM

Stacks blockchain node process manager.

## Getting Started

STNM developed with python. Requires python 3.5+ and pip3. Compatible with Linux and macOS.

### Linux users

Make sure you have pip3 and python3dev packages installed on your system.

`$ apt install python3-pip python3-dev` 

### macOS users
You can download python installer from here https://www.python.org/downloads/ if you don't have it installed on your system.

### Installation with pip3 (easier way)
 
`$ pip3 install stnm` 

### Installation from source code

`$ git clone https://github.com/talhasch/stnm && cd stnm && pip3 install -e .` 

